import { css, LitElement, html } from 'lit-element';

const BsBreadcrumbItemCss = css`
    :host {
        padding-left: var(--breadcrumb-item-padding-left, 0.5rem);
    }

    :host([active]) {
        color: var(--breadcrumb-item-active-color, #6c757d);
    }

    :host::before {
        content: var(--breadcrumb-item-divider-content, "/");
        color: var(--breadcrumb-item-divider-color, #6c757d);
        display: var(--breadcrumb-item-divider-display, inline-block);
        padding-right: var(--breadcrumb-item-divider-padding-right, 0.3rem);
        text-decoration: var(--breadcrumb-item-divider-text-decoration, none);
    }

    a {
        color: var(--breadcrumb-item-link-color, #007bff);
        text-decoration: var(--breadcrumb-item-link-text-decoration, none);
        background-color: var(--breadcrumb-item-link-bg-color, transparent);
        -webkit-text-decoration-skip: objects;
    }

    a:hover {
        color: var(--breadcrumb-link-item-link-hover-color, #0056b3);
        text-decoration: var(--breadcrumb-item-link-hover-text-decoration, underline);
    }

    a:not([href]):not([tabindex]) {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):hover,
    a:not([href]):not([tabindex]):focus {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):focus {
        outline: 0;
    }
`;

const BsBreadcrumbRebootCss = css`
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    :host,
    :host::before,
    :host::after {
        box-sizing: border-box;
    }
`;

/**
 * Breadcrumb item
 *
 * @element bs-breadcrumb-item
 *
 * @attribute title - The breadcrub title
 * @attribute active - Indicates if this is the last breadcrumb item
 * @attribute href - The hyper link to point to (not applicable if last breadcrumb item)
 * @attribute target - The context target (not applicable if last breadcrumb item)
 *
 * @property {String} title - Indicates whether or not the alert can be dismissed. default: false
 * @property {String} active - Indicates if this is the last breadcrumb item. default: false
 * @property {String} href - The hyper link to point to (not applicable if last breadcrumb item). default: ''
 * @property {String} target - The context target (not applicable if last breadcrumb item). default: _self
 *
 * @cssproperty --breadcrumb-item-padding-left Left padding. default: 0.5rem
 * @cssproperty --breadcrumb-item-active-color Text color when active attribute is used. default: #6c757d
 * @cssproperty --breadcrumb-item-divider-content Divider content. default: "/"
 * @cssproperty --breadcrumb-item-divider-color Divider color. default: #6c757d
 * @cssproperty --breadcrumb-item-divider-display Divider display. default: inline-block
 * @cssproperty --breadcrumb-item-divider-padding-right Divider right padding. default: 0.3rem
 * @cssproperty --breadcrumb-item-divider-text-decoration Divider text decoration. default: none
 * @cssproperty --breadcrumb-item-link-color Link text color. default: #007bff
 * @cssproperty --breadcrumb-item-link-text-decoration Link text decoration. default: none
 * @cssproperty --breadcrumb-item-link-bg-color Link background color. default: transparent
 * @cssproperty --breadcrumb-link-item-link-hover-color Link hover text color. default: #0056b3
 * @cssproperty --breadcrumb-item-link-hover-text-decoration Link hover text decoration. default: underline
 */

class BsBreadcrumbItem extends LitElement {
  static get properties() {
    return {
      title: {
        type: String,
        reflect: true
      },
      href: {
        type: String,
        reflect: true
      },
      target: {
        type: String,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      }
    };
  }

  static get styles() {
    return [BsBreadcrumbRebootCss, BsBreadcrumbItemCss];
  }

  render() {
    return html`
            ${this._selectTemplateToLoad()}
        `;
  }

  constructor() {
    super();
    this.title = "";
    this.href = "";
    this.target = "_self";
    this.active = false;
  }
  /**
   * If the element is set as active (meaning the last breadcrumb item)
   * then the template will bu just the title. Otherwise it will be
   * an anchor link.
   *
   * @return  {TemplateResult}  the template to render
   */


  _selectTemplateToLoad() {
    if (this.active) {
      return html`
                <span>${this.title}</span>
            `;
    } else {
      return html`
                <a href="${this.href}">${this.title}</a>
            `;
    }
  }

}
if (!window.customElements.get("bs-breadcrumb-item")) window.customElements.define("bs-breadcrumb-item", BsBreadcrumbItem);

const BsBreadcrumbCss = css`
    :host {
        display: var(--breadcrumb-display, flex);
        flex-wrap: var(--breadcrumb-flex-wrap, wrap);
        padding-top: var(--breadcrumb-padding-top, 0.75rem);
        padding-bottom: var(--breadcrumb-padding-bottom, 0.75rem);
        padding-right: var(--breadcrumb-padding-right, 1rem);
        padding-left: var(--breadcrumb-padding-left, 1rem);
        margin-bottom: var(--breadcrumb-margin-bottom, 1rem);
        background-color: var(--breadcrumb-bg-color, #e9ecef);
        border-radius: var(--breadcrumb-border-radius, 0.25rem);
    }
`;

/**
 * Breadcrumb Element
 *
 * @element bs-breadcrumb
 *
 * @slot Slot for breadcrub items content
 *
 * @cssproperty --breadcrumb-display - Display property. default: flex
 * @cssproperty --breadcrumb-flex-wrap - Flex-wrap. default: wrap
 * @cssproperty --breadcrumb-padding-top - Padding top. default: 0.75rem
 * @cssproperty --breadcrumb-padding-bottom - Padding bottom. default: 0.75rem
 * @cssproperty --breadcrumb-padding-right - Padding right. default: 1rem
 * @cssproperty --breadcrumb-padding-left - Padding left. default: 1rem
 * @cssproperty --breadcrumb-margin-bottom - Margin bottom. default: 1rem
 * @cssproperty --breadcrumb-bg-color - Background color. default: #e9ecef
 * @cssproperty --breadcrumb-border-radius - Border radius. default: 0.25rem
 */

class BsBreadcrumb extends LitElement {
  static get styles() {
    return [BsBreadcrumbRebootCss, BsBreadcrumbCss];
  }

  render() {
    return html`
            <slot></slot>
        `;
  }
  /**
   * When breadcrumb item is first updated:
   *   1) The aria label is added to the host element
   *   2) The first breadcrumb item style is changed
   *
   * @param   {Map}  _updatedProperties  the Map with updated properties
   *
   * @return  {void}
   */


  firstUpdated(_updatedProperties) {
    super.firstUpdated(_updatedProperties);

    this._addAriaLabel();

    this._removeDividerFromFirstBreadcrumItem();
  }
  /**
   * Adds an arial label attribute with value of 'breadcrumb'
   *
   * @return  {void}
   */


  _addAriaLabel() {
    this.setAttribute("aria-label", "breadcrumb");
  }
  /**
   * Reset the left padding and remove the ::before content for the first breadcrumb item
   *
   * @return  {void}
   */


  _removeDividerFromFirstBreadcrumItem() {
    const breadcrumbItemElement = this._findFirstBreadcrumbItem();

    if (!breadcrumbItemElement) {
      return;
    }
    /** @type {HTMLElement} */


    breadcrumbItemElement.style.setProperty("--breadcrumb-item-padding-left", "0");
    /** @type {HTMLElement} */

    breadcrumbItemElement.style.setProperty("--breadcrumb-item-divider-content", "none");
  }
  /**
   * Finds the first breadcrumb item element in the slotted content
   *
   * @return  {Node}  The first BsBreadcrumbItem <bs-breadcrumb-item> found
   */


  _findFirstBreadcrumbItem() {
    const slot = this.shadowRoot.querySelector("slot");
    const slottedElements = slot.assignedElements();
    return slottedElements.find(element => this._isBreadcrumbItemElement(element));
  }
  /**
   * Verify that the given element is an HTMLElement and it is an instance of BsBreadcrumbItem
   *
   * @param   {Element}  element  The node to verify
   *
   * @return  {Boolean}  true if the node is an HTMLElement and an instance of BsBreadcrumbItem
   */


  _isBreadcrumbItemElement(element) {
    return element.nodeType === Node.ELEMENT_NODE && (element.localName === "bs-breadcrumb-item" || element instanceof BsBreadcrumbItem);
  }

}
if (!window.customElements.get("bs-breadcrumb")) window.customElements.define("bs-breadcrumb", BsBreadcrumb);

export { BsBreadcrumb, BsBreadcrumbCss, BsBreadcrumbItem, BsBreadcrumbItemCss };
//# sourceMappingURL=index.js.map
